IXRoadIdentifier
Namespace: XRoadLib.Headers
Globally unique identifier in the XRoad system. Identifier consists of object type specifier and list of hierarchical codes (starting with code that identifiers the XRoad instance).
Instance members
| Instance member | Description |
MemberClass
Signature: string
Modifiers: abstract |
Type of the member (company, government institution, private person, etc.) |
MemberCode
Signature: string
Modifiers: abstract |
Code that uniquely identifies a member of given member type. |
ObjectType
Signature: XRoadObjectType
Modifiers: abstract |
Specifies identifier type. |
ServiceCode
Signature: string
Modifiers: abstract |
Code that uniquely identifies a service offered by given XRoad member or subsystem. |
ServiceVersion
Signature: string
Modifiers: abstract |
Version of the service. |
SubsystemCode
Signature: string
Modifiers: abstract |
Code that uniquely identifies a subsystem of given XRoad member. |
XRoadInstance
Signature: string
Modifiers: abstract |
Identifies the XRoad instance. This field is applicable to all identifier types. |